###########
Config main
###########

The main page of the config tab is for setting various directories and overall settings for ROMSearch. By hovering
over each setting, a tooltip will appear with a brief description of the item

.. image:: ../images/config_main.png
